==> deltafi-common-0.98.2-sources.jar: org/deltafi/common/types/ActionEventInput.java <==
/**
 *    DeltaFi - Data transformation and enrichment platform
 *
 *    Copyright 2022 DeltaFi Contributors <deltafi@deltafi.org>
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.deltafi.common.types;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.OffsetDateTime;
import java.util.List;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder(builderMethodName = "newBuilder")
public class ActionEventInput {
  private String did;
  private String action;
  private OffsetDateTime start;
  private OffsetDateTime stop;
  private OffsetDateTime time;
  private ActionEventType type;
  private DomainResultInput domain;
  private TransformInput transform;
  private LoadInput load;
  private EnrichInput enrich;
  private FormatInput format;
  private List<FormatInput> formatMany;
  private ErrorInput error;
  private FilterInput filter;
  private List<SplitInput> split;
}

==> deltafi-common-0.99.3.1-sources.jar: org/deltafi/common/types/ActionEventInput.java <==
/**
 *    DeltaFi - Data transformation and enrichment platform
 *
 *    Copyright 2022 DeltaFi Contributors <deltafi@deltafi.org>
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.deltafi.common.types;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.OffsetDateTime;
import java.util.List;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder(builderMethodName = "newBuilder")
public class ActionEventInput {
  private String did;
  private String action;
  private OffsetDateTime start;
  private OffsetDateTime stop;
  private OffsetDateTime time;
  private ActionEventType type;
  private DomainEvent domain;
  private TransformEvent transform;
  private LoadEvent load;
  private EnrichEvent enrich;
  private FormatEvent format;
  private List<FormatEvent> formatMany;
  private ErrorEvent error;
  private FilterEvent filter;
  private List<SplitEvent> split;
}
